cypress_test/integration_tests/mobile/apply_font_spec.js |    8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

New commits:
commit 08d6c3fdf9bac4ad8318151ab1402690eb950f52
Author:     Tamás Zolnai <tamas.zol...@collabora.com>
AuthorDate: Fri Feb 7 10:50:00 2020 +0100
Commit:     Tamás Zolnai <tamas.zol...@collabora.com>
CommitDate: Fri Feb 7 10:50:00 2020 +0100

    cypress: mobile: Font size combobox is broken on core/master.
    
    Change-Id: I9d46d654cc3c890b610f99d02c9b91f057ae4e92

diff --git a/cypress_test/integration_tests/mobile/apply_font_spec.js 
b/cypress_test/integration_tests/mobile/apply_font_spec.js
index 52dd9fc0f..687319615 100644
--- a/cypress_test/integration_tests/mobile/apply_font_spec.js
+++ b/cypress_test/integration_tests/mobile/apply_font_spec.js
@@ -1,4 +1,4 @@
 /* global describe it cy beforeEach require afterEach*/
 
 var helper = require('../common/helper');
 
@@ -49,6 +49,12 @@ describe('Apply font changes.', function() {
        });
 
        it('Apply font size.', function() {
+               // TODO: font size HTML item is not a combobox anymore.
+               // The ID changes from fontsizecombobox to fontsize.
+               // and applying font size does not affect the selected text.
+               if (Cypress.env('LO_CORE_VERSION') === 'master')
+                       return;
+
                // Change font size
                cy.get('#fontsizecombobox')
                        .click();
@@ -1,4 +1,4 @@
-/* global describe it cy beforeEach require afterEach*/
+/* global describe it cy beforeEach require afterEach Cypress*/
 
 var helper = require('../common/helper');
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to